@@ -3,8 +3,8 @@ PdfInfoExtractor
 
 """
 
-from PdfInfoExtractor import ImagesExtractor, ClassifyFiles, extract_info
+from utilities import ImagesExtractor, ClassifyFiles, extract_info
 
-__version__ = "0.1.10"
+__version__ = "0.1.11"
 __author__ = 'Steve Richards, Mehak Singal, Nidhish Kumar'
 # __credits__ = 'Argonne National Laboratory'
\ No newline at end of file
